# distributions_km package

	Sample package with Gaussian and Binomial modules. 

# Files
	The package consists General Distribution, Gaussian and Binomial distribution file
    
    
    
# Installation